@@ -38,7 +38,6 @@ PYTHON=python3
 
 KEY_FILE="E:\\xpra.pfx"
 DIST="./dist"
-BUILD_OPTIONS=""
 
 if [ "${CLIENT_ONLY}" == "1" ]; then
 	BUILD_OPTIONS="${BUILD_OPTIONS} --without-enc_x264 --without-nvenc --without-nvfbc"
@@ -297,7 +296,7 @@ fi
 if [ "${DO_TESTS}" == "1" ]; then
 	echo "* Running unit tests"
 	UNITTEST_LOG="packaging/MSWindows/unittest.log"
-	PYTHONPATH=.:./tests/unittests XPRA_COMMAND="./scripts/xpra" ${PYTHON} ./unittests/unit/run.py >& ${UNITTEST_LOG}
+	PYTHONPATH=.:./tests/unittests XPRA_COMMAND="./fs/bin/xpra" ${PYTHON} ./unittests/unit/run.py >& ${UNITTEST_LOG}
 	if [ "$?" != "0" ]; then
 		echo "ERROR: unittests have failed, see ${UNITTEST_LOG}:"
 		tail -n 20 "${UNITTEST_LOG}"
