@@ -1,6 +1,6 @@
 #!/bin/bash
 
-PYTHON="python3"
+export PYTHON="python3"
 PYTHON_MAJOR_VERSION=`$PYTHON -c 'import sys;sys.stdout.write("%s" % sys.version_info[0])'`
 PYTHON_MINOR_VERSION=`$PYTHON -c 'import sys;sys.stdout.write("%s" % sys.version_info[1])'`
 
@@ -12,7 +12,7 @@ STRIP_SOURCE="${STRIP_SOURCE:=0}"
 STRIP_OPENGL="${STRIP_OPENGL:=$STRIP_DEFAULT}"
 CLIENT_ONLY="${CLIENT_ONLY:=0}"
 
-DO_TESTS="${DO_TESTS:-1}"
+DO_TESTS="${DO_TESTS:-0}"
 
 BUILDNO="${BUILDNO:="0"}"
 APP_DIR="./image/Xpra.app"
@@ -93,7 +93,7 @@ if [ "${DO_TESTS}" == "1" ]; then
 	mkdir ./tmpdir
 	#make sure the unit tests can run "python3 xpra ...":
 	rm -f ./xpra >& /dev/null
-	ln -sf ../scripts/xpra .
+	ln -sf ../fs/bin/xpra .
 	UNITTEST_LOG=`pwd`/unittest.log
 	echo "running unit tests (see ${UNITTEST_LOG} - this may take a minute or two)"
 	TMPDIR=./tmpdir XPRA_COMMAND="$PYTHON ./xpra" XPRA_NODOCK_COMMAND="$PYTHON ./xpra" XPRA_SOUND_COMMAND="$PYTHON ./xpra" PYTHONPATH=. ./unit/run.py >& ${UNITTEST_LOG}
@@ -170,7 +170,7 @@ if [ ! -e "JHBUILD_PREFIX}/share/icons/hicolor/index.theme" ]; then
 	touch "${JHBUILD_PREFIX}/share/icons/hicolor/index.theme"
 fi
 #we have to make sure we use python2 here (not ported yet):
-PYTHON=${PYTHON} python2 ~/.local/bin/gtk-mac-bundler Xpra.bundle
+gtk-mac-bundler Xpra.bundle
 if [ "$?" != "0" ]; then
 	echo "ERROR: gtk-mac-bundler failed"
 	exit 1
