@@ -1,25 +1,25 @@
 BUILD_BIT='64bit'
 BUILD_CPU='x86_64'
-BUILD_DATE='2022-11-28'
+BUILD_DATE='2023-03-10'
 BUILD_MACHINE='x86_64'
-BUILD_OS='Linux Fedora 36 ThirtySix'
-BUILD_TIME='14:42'
+BUILD_OS='Linux Fedora 37 ThirtySeven'
+BUILD_TIME='16:32'
 BUILT_BY='antoine'
 BUILT_ON='localhost.localdomain'
 COMPILER_VERSION='gcc (GCC) 12.2.1 20221121 (Red Hat 12.2.1-4)'
-CYTHON_VERSION='0.29.30'
-LINKER_VERSION='GNU ld version 2.37-37.fc36'
-PYTHON_VERSION='3.10.8'
-lib_gobject_introspection='1.72.0'
-lib_gtk='3.24.35'
-lib_gtk_x11='3.24.35'
+CYTHON_VERSION='3.0.0a11'
+LINKER_VERSION='GNU ld version 2.38-25.fc37'
+PYTHON_VERSION='3.11.2'
+lib_gobject_introspection='1.74.0'
+lib_gtk='3.24.37'
+lib_gtk_x11='3.24.37'
 lib_nvenc='10'
 lib_nvfbc='6.0'
 lib_py3cairo='1.21.0'
-lib_pygobject='3.42.1'
-lib_python3='3.10'
-lib_vpx='1.11.0'
-lib_x11='1.7.3.1'
+lib_pygobject='3.42.2'
+lib_python3='3.11'
+lib_vpx='1.12.0'
+lib_x11='1.8.4'
 lib_x265='3.5'
 lib_xcomposite='0.4.5'
 lib_xdamage='1.1.5'
