@@ -46,6 +46,7 @@ notifylog = Logger("osx", "notify")
 
 OSX_FOCUS_WORKAROUND = envint("XPRA_OSX_FOCUS_WORKAROUND", 2000)
 SLEEP_HANDLER = envbool("XPRA_OSX_SLEEP_HANDLER", True)
+EVENT_LISTENER = envbool("XPRA_OSX_EVENT_LISTENER", True)
 OSX_WHEEL_MULTIPLIER = envint("XPRA_OSX_WHEEL_MULTIPLIER", 100)
 OSX_WHEEL_PRECISE_MULTIPLIER = envint("XPRA_OSX_WHEEL_PRECISE_MULTIPLIER", 1)
 OSX_WHEEL_DIVISOR = envint("XPRA_OSX_WHEEL_DIVISOR", 10)
@@ -584,10 +585,10 @@ class Delegate(NSObject):
     @objc.python_method
     def register_sleep_handlers(self):
         log("register_sleep_handlers()")
-        workspace          = NSWorkspace.sharedWorkspace()
-        notificationCenter = workspace.notificationCenter()
+        self.workspace          = NSWorkspace.sharedWorkspace()
+        self.notificationCenter = self.workspace.notificationCenter()
         def add_observer(fn, val):
-            notificationCenter.addObserver_selector_name_object_(self, fn, val, None)
+            self.notificationCenter.addObserver_selector_name_object_(self, fn, val, None)
         #NSWorkspaceWillPowerOffNotification
         add_observer(self.receiveSleepNotification_, NSWorkspaceWillSleepNotification)
         add_observer(self.receiveWakeNotification_, NSWorkspaceDidWakeNotification)
@@ -708,10 +709,11 @@ class ClientExtras:
         self.client = None
 
     def ready(self):
-        try:
-            self.setup_event_listener()
-        except Exception:
-            log.error("Error setting up OSX event listener", exc_info=True)
+        if EVENT_LISTENER:
+            try:
+                self.setup_event_listener()
+            except:
+                log.error("Error setting up OSX event listener", exc_info=True)
 
     def setup_event_listener(self):
         log("setup_event_listener()")
