@@ -35,7 +35,6 @@ from xpra.platform.win32.common import (
     GetIntSystemParametersInfo,
     GetUserObjectInformationA, OpenInputDesktop, CloseDesktop,
     GetMonitorInfo,
-    user32,
     )
 from xpra.common import KeyEvent
 from xpra.util import AdHocStruct, csv, envint, envbool, typedict
@@ -53,6 +52,7 @@ USE_NATIVE_TRAY = envbool("XPRA_USE_NATIVE_TRAY", True)
 REINIT_VISIBLE_WINDOWS = envbool("XPRA_WIN32_REINIT_VISIBLE_WINDOWS", True)
 SCREENSAVER_LISTENER_POLL_DELAY = envint("XPRA_SCREENSAVER_LISTENER_POLL_DELAY", 10)
 APP_ID = os.environ.get("XPRA_WIN32_APP_ID", "Xpra")
+MONITOR_DPI = envbool("XPRA_WIN32_MONITOR_DPI", True)
 
 
 PyCapsule_GetPointer = pythonapi.PyCapsule_GetPointer
@@ -93,8 +93,6 @@ CLIP_CURSOR = WINDOW_HOOKS and envbool("XPRA_WIN32_CLIP_CURSOR", True)
 MAX_SIZE_HINT = WINDOW_HOOKS and envbool("XPRA_WIN32_MAX_SIZE_HINT", False)
 LANGCHANGE = WINDOW_HOOKS and envbool("XPRA_WIN32_LANGCHANGE", True)
 
-DPI_AWARE = envbool("XPRA_DPI_AWARE", True)
-DPI_AWARENESS = envint("XPRA_DPI_AWARENESS", 1)
 FORWARD_WINDOWS_KEY = envbool("XPRA_FORWARD_WINDOWS_KEY", True)
 WHEEL = envbool("XPRA_WHEEL", True)
 WHEEL_DELTA = envint("XPRA_WIN32_WHEEL_DELTA", 120)
@@ -104,11 +102,12 @@ log("win32 gui settings: CONSOLE_EVENT_LISTENER=%s, USE_NATIVE_TRAY=%s, WINDOW_H
     CONSOLE_EVENT_LISTENER, USE_NATIVE_TRAY, WINDOW_HOOKS, GROUP_LEADER)
 log("win32 gui settings: UNDECORATED_STYLE=%s, CLIP_CURSOR=%s, MAX_SIZE_HINT=%s, LANGCHANGE=%s",
     UNDECORATED_STYLE, CLIP_CURSOR, MAX_SIZE_HINT, LANGCHANGE)
-log("win32 gui settings: DPI_AWARE=%s, DPI_AWARENESS=%s, FORWARD_WINDOWS_KEY=%s, WHEEL=%s, WHEEL_DELTA=%s",
-    DPI_AWARE, DPI_AWARENESS, FORWARD_WINDOWS_KEY, WHEEL, WHEEL_DELTA)
+log("win32 gui settings: FORWARD_WINDOWS_KEY=%s, WHEEL=%s, WHEEL_DELTA=%s",
+    FORWARD_WINDOWS_KEY, WHEEL, WHEEL_DELTA)
 
 
 def do_init():
+    from xpra.platform.win32.dpi import init_dpi
     init_dpi()
     if APP_ID:
         init_appid()
@@ -118,33 +117,6 @@ def do_init():
     except Exception:
         log.error("Error: failed to setup dwm window color matching", exc_info=True)
 
-def init_dpi():
-    #tell win32 we handle dpi
-    if not DPI_AWARE:
-        screenlog.warn("SetProcessDPIAware not set due to environment override")
-        return
-    try:
-        SetProcessDPIAware = user32.SetProcessDPIAware
-        dpiaware = SetProcessDPIAware()
-        screenlog("SetProcessDPIAware: %s()=%s", SetProcessDPIAware, dpiaware)
-        assert dpiaware!=0
-    except Exception as e:
-        screenlog.warn("SetProcessDPIAware() failed: %s", e)
-    if DPI_AWARENESS<=0:
-        screenlog.warn("SetProcessDPIAwareness not set due to environment override")
-        return
-    try:
-        Process_System_DPI_Aware        = 1
-        Process_DPI_Unaware             = 0
-        Process_Per_Monitor_DPI_Aware   = 2
-        assert DPI_AWARENESS in (Process_System_DPI_Aware, Process_DPI_Unaware, Process_Per_Monitor_DPI_Aware)
-        SetProcessDpiAwarenessInternal = user32.SetProcessDpiAwarenessInternal
-        dpiawareness = SetProcessDpiAwarenessInternal(DPI_AWARENESS)
-        screenlog("SetProcessDPIAwareness: %s(%s)=%s", SetProcessDpiAwarenessInternal, DPI_AWARENESS, dpiawareness)
-        assert dpiawareness==0
-    except Exception as e:
-        screenlog("SetProcessDpiAwarenessInternal(%s) failed: %s", DPI_AWARENESS, e)
-        screenlog(" (not available on MS Windows before version 8.1)")
 
 def init_appid():
     from ctypes import HRESULT
@@ -354,14 +326,14 @@ WS_NAMES = {
             }
 
 def style_str(style):
-    return csv([s for c,s in WS_NAMES.items() if (c & style)==c])
+    return csv(s for c,s in WS_NAMES.items() if (c & style)==c)
 
 def pointer_grab(window, *args):
     hwnd = get_window_handle(window)
     grablog("pointer_grab%s window=%s, hwnd=%s", args, window, hwnd)
     if not hwnd:
-        window._client.pointer_grabbed = False
-        return
+        window._client.pointer_grabbed = None
+        return False
     wrect = RECT()
     GetWindowRect(hwnd, byref(wrect))
     grablog("GetWindowRect(%i)=%s", hwnd, wrect)
@@ -379,20 +351,24 @@ def pointer_grab(window, *args):
     if style & win32con.WS_CAPTION:
         top += GetSystemMetrics(win32con.SM_CYCAPTION)
     grablog(" window style=%s, SIZEFRAME=%s, top=%i", style_str(style), (bx, by), top)
-    clip = RECT(wrect.left+bx, wrect.top+top, wrect.right-bx, wrect.bottom-by)
-    grablog("ClipCursor(%s)", clip)
-    ClipCursor(clip)
-    window._client.pointer_grabbed = True
+    coords = wrect.left+bx, wrect.top+top, wrect.right-bx, wrect.bottom-by
+    clip = RECT(*coords)
+    r = ClipCursor(clip)
+    grablog("ClipCursor%s=%s", coords, r)
+    window._client.pointer_grabbed = window._id
+    return True
 
 def pointer_ungrab(window, *args):
     hwnd = get_window_handle(window)
     client = window._client
     grablog("pointer_ungrab%s window=%s, hwnd=%s, pointer_grabbed=%s",
             args, window, hwnd, client.pointer_grabbed)
-    if hwnd:
-        grablog("ClipCursor(None)")
-        ClipCursor(None)
-    client.pointer_grabbed = False
+    if not hwnd:
+        return False
+    grablog("ClipCursor(None)")
+    ClipCursor(None)
+    client.pointer_grabbed = None
+    return True
 
 def fixup_window_style(self, *_args):
     """ a fixup function we want to call from other places """
@@ -929,6 +905,90 @@ def show_desktop(b):
         log.warn("failed to call show_desktop(%s): %s", b, e)
 
 
+
+def get_monitors_info(xscale=1, yscale=1):
+    from xpra.gtk_common import gtk_util
+    monitors_info = gtk_util.get_monitors_info(xscale, yscale)
+    if MONITOR_DPI:
+        #try to get more precise data by querying the DPI using comtypes:
+        from xpra.platform.win32.comtypes_util import CIMV2_Query
+        with CIMV2_Query("SELECT * FROM Win32_DesktopMonitor") as res:
+            index = 0
+            for monitor in res:
+                dminfo = dict((k, monitor.Properties_[k].Value) for k in (
+                    "DeviceID", "MonitorManufacturer", "MonitorType",
+                    "ScreenWidth", "ScreenHeight",
+                    "PixelsPerXLogicalInch", "PixelsPerYLogicalInch",
+                    ))
+                log(f"Win32_DesktopMonitor {index}: {dminfo}")
+                manufacturer = dminfo["MonitorManufacturer"]
+                model = dminfo["MonitorType"]
+                #find this monitor entry in the gtk info:
+                mmatch = None
+                for monitor_info in monitors_info.values():
+                    if monitor_info.get("manufacturer")==manufacturer and monitor_info.get("model")==model:
+                        mmatch = monitor_info
+                        break
+                if mmatch:
+                    dpix = dminfo["PixelsPerXLogicalInch"]
+                    dpiy = dminfo["PixelsPerYLogicalInch"]
+                    #get the screen size from gtk because Win32_DesktopMonitor can be None!
+                    width = dminfo["ScreenWidth"] or mmatch["geometry"][2]
+                    height = dminfo["ScreenHeight"] or mmatch["geometry"][3]
+                    if dpix>0 and dpiy>0 and width>0 and height>0:
+                        mmatch.update({
+                            "dpi-x" : dpix,
+                            "dpi-y" : dpiy,
+                            "width-mm"  : round(width*25.4/dpix),
+                            "height-mm" : round(height*25.4/dpiy),
+                            })
+                index += 1
+    return monitors_info
+
+
+
+TaskbarLib = None
+def getTaskbar():
+    # pylint: disable=import-outside-toplevel
+    global TaskbarLib
+    if TaskbarLib is None:
+        try:
+            from xpra.platform.win32.comtypes_util import QuietenLogging, find_tlb_file, comtypes_init
+            taskbar_tlb = find_tlb_file("TaskbarLib.tlb")
+            if not taskbar_tlb:
+                log.warn("Warning: 'TaskbarLib.tlb' was not found")
+                log.warn(" taskbar integration cannot be enabled")
+                TaskbarLib = False
+                return None
+            comtypes_init()
+            with QuietenLogging():
+                import comtypes.client as cc  # @UnresolvedImport
+                cc.GetModule(taskbar_tlb)
+                import comtypes.gen.TaskbarLib as tbl  # @UnresolvedImport
+                TaskbarLib = tbl
+                log(f"loaded {taskbar_tlb!r}: {TaskbarLib}")
+        except Exception as e:
+            log("getTaskbar()", exc_info=True)
+            log.error(f"Error: failed to load taskbar library from {taskbar_tlb!r}")
+            log.estr(e)
+            TaskbarLib = False
+    if not TaskbarLib:
+        return None
+    taskbar = cc.CreateObject("{56FDF344-FD6D-11d0-958A-006097C9A090}", interface=TaskbarLib.ITaskbarList3)
+    taskbar.HrInit()
+    return taskbar
+
+
+def set_window_progress(window, pct):
+    taskbar = getattr(window, "taskbar", None)
+    if not taskbar:
+        taskbar = getTaskbar()
+        window.taskbar = taskbar
+    if taskbar:
+        handle = get_window_handle(window)
+        taskbar.SetProgressValue(handle, max(0, min(100, pct)), 100)
+
+
 WM_WTSSESSION_CHANGE = 0x02b1
 WTS_CONSOLE_CONNECT         = 0x1
 WTS_CONSOLE_DISCONNECT      = 0x2
@@ -1255,6 +1315,9 @@ def main():
         fake_client.suspend = suspend
         fake_client.resume = resume
         fake_client.keyboard_helper = None
+        def noop(*args):
+            pass
+        fake_client.timeout_add = noop
         def signal_quit(*_args):
             loop.quit()
         fake_client.signal_disconnect_and_quit = signal_quit
